@@ -7,11 +7,15 @@
 // specific language governing permissions and limitations relating to use of the SAFE Network
 // Software.
 
-use super::{metadata::get_metadata, ProcessedFiles};
-use crate::{app::consts::*, Error, Result, Safe, XorUrl};
+use super::{metadata::get_metadata, FilesMapChange, ProcessedFiles};
+use crate::{Error, Result, Safe, XorUrl};
 use bytes::Bytes;
 use log::info;
-use std::{collections::BTreeMap, fs, path::Path};
+use safe_network::client::Error as ClientError;
+use std::{
+    fs,
+    path::{Path, PathBuf},
+};
 use walkdir::{DirEntry, WalkDir};
 
 const MAX_RECURSIVE_DEPTH: usize = 10_000;
@@ -27,20 +31,31 @@ pub(crate) async fn upload_file_to_net(
     })?;
     let data = Bytes::from(data);
 
-    let mime_type = mime_guess::from_path(&path);
-    match safe
-        .store_public_bytes(data.to_owned(), mime_type.first_raw(), dry_run)
+    let mut mime_type_for_xorurl = mime_guess::from_path(&path).first_raw();
+    let result = match safe
+        .store_public_bytes(data.to_owned(), mime_type_for_xorurl, dry_run)
         .await
     {
         Ok(xorurl) => Ok(xorurl),
-        Err(err) => {
+        Err(Error::InvalidMediaType(_)) => {
             // Let's then upload it and set media-type to be simply raw content
-            if let Error::InvalidMediaType(_) = err {
-                safe.store_public_bytes(data, None, dry_run).await
-            } else {
-                Err(err)
-            }
+            mime_type_for_xorurl = None;
+            safe.store_public_bytes(data.clone(), mime_type_for_xorurl, dry_run)
+                .await
         }
+        other_err => other_err,
+    };
+
+    // If the upload verification failed, the file could still have been uploaded successfully,
+    // thus let's report the error but providing the xorurl for the user to be aware of.
+    if let Err(Error::ClientError(ClientError::NotEnoughChunksRetrieved { .. })) = result {
+        // let's obtain the xorurl with using dry-run mode
+        let xorurl = safe
+            .store_public_bytes(data, mime_type_for_xorurl, true)
+            .await?;
+        Err(Error::ContentUploadVerificationFailed(xorurl))
+    } else {
+        result
     }
 }
 
@@ -54,20 +69,20 @@ pub(crate) fn normalise_path_separator(from: &str) -> String {
 // the list of files with their corresponding XOR-URLs
 pub(crate) async fn file_system_dir_walk(
     safe: &mut Safe,
-    location: &str,
+    location: &Path,
     recursive: bool,
     follow_links: bool,
     dry_run: bool,
 ) -> Result<ProcessedFiles> {
-    let file_path = Path::new(location);
-    info!("Reading files from {}", file_path.display());
-    let (metadata, _) = get_metadata(file_path, follow_links)?;
+    info!("Reading files from {}", location.display());
+
+    let (metadata, _) = get_metadata(location, follow_links)?;
     if metadata.is_dir() || !recursive {
         // TODO: option to enable following symlinks?
         // We now compare both FilesMaps to upload the missing files
         let max_depth = if recursive { MAX_RECURSIVE_DEPTH } else { 1 };
-        let mut processed_files = BTreeMap::new();
-        let children_to_process = WalkDir::new(file_path)
+        let mut processed_files = ProcessedFiles::default();
+        let children_to_process = WalkDir::new(location)
             .follow_links(follow_links)
             .into_iter()
             .filter_entry(|e| valid_depth(e, max_depth))
@@ -77,13 +92,13 @@ pub(crate) async fn file_system_dir_walk(
             let current_file_path = child.path();
             let current_path_str = current_file_path.to_str().unwrap_or("").to_string();
             info!("Processing {}...", current_path_str);
-            let normalised_path = normalise_path_separator(&current_path_str);
+            let normalised_path = PathBuf::from(normalise_path_separator(&current_path_str));
 
             let result = get_metadata(current_file_path, follow_links);
             match result {
                 Ok((metadata, _)) => {
                     if metadata.file_type().is_dir() {
-                        if idx == 0 && normalised_path.ends_with('/') {
+                        if idx == 0 && normalised_path.display().to_string().ends_with('/') {
                             // If the first directory ends with '/' then it is
                             // the root, and we are only interested in the children,
                             // so we skip it.
@@ -102,41 +117,39 @@ pub(crate) async fn file_system_dir_walk(
                         // Callers can inspect the file's metadata.
                         processed_files.insert(
                             normalised_path.clone(),
-                            (CONTENT_ADDED_SIGN.to_string(), String::default()),
+                            FilesMapChange::Added(String::default()),
                         );
                     }
+
                     if metadata.file_type().is_symlink() {
                         processed_files.insert(
                             normalised_path.clone(),
-                            (CONTENT_ADDED_SIGN.to_string(), String::default()),
+                            FilesMapChange::Added(String::default()),
                         );
                     }
+
                     if metadata.file_type().is_file() {
                         match upload_file_to_net(safe, current_file_path, dry_run).await {
                             Ok(xorurl) => {
-                                processed_files.insert(
-                                    normalised_path,
-                                    (CONTENT_ADDED_SIGN.to_string(), xorurl),
-                                );
+                                processed_files
+                                    .insert(normalised_path, FilesMapChange::Added(xorurl));
                             }
                             Err(err) => {
+                                info!("Skipping file \"{}\". {}", normalised_path.display(), err);
                                 processed_files.insert(
-                                    normalised_path.clone(),
-                                    (CONTENT_ERROR_SIGN.to_string(), format!("<{}>", err)),
+                                    normalised_path,
+                                    FilesMapChange::Failed(format!("{}", err)),
                                 );
-                                info!("Skipping file \"{}\". {}", normalised_path, err);
                             }
                         }
                     }
                 }
                 Err(err) => {
-                    processed_files.insert(
-                        normalised_path.clone(),
-                        (CONTENT_ERROR_SIGN.to_string(), format!("<{}>", err)),
-                    );
                     info!(
                         "Skipping file \"{}\" since no metadata could be read from local location: {:?}",
-                        normalised_path, err);
+                        normalised_path.display(), err);
+                    processed_files
+                        .insert(normalised_path, FilesMapChange::Failed(format!("{}", err)));
                 }
             }
         }
@@ -148,7 +161,7 @@ pub(crate) async fn file_system_dir_walk(
         // or remove the 'recursive' flag from the args
         Err(Error::InvalidInput(format!(
             "'{}' is not a directory. The \"recursive\" arg is only supported for folders.",
-            location
+            location.display()
         )))
     }
 }
@@ -167,32 +180,28 @@ fn valid_depth(entry: &DirEntry, max_depth: usize) -> bool {
 // the obtained XOR-URL in the single file list returned
 pub(crate) async fn file_system_single_file(
     safe: &mut Safe,
-    location: &str,
+    location: &Path,
     dry_run: bool,
 ) -> Result<ProcessedFiles> {
-    let file_path = Path::new(location);
-    info!("Reading file {}", file_path.display());
-    let (metadata, _) = get_metadata(file_path, true)?; // follows symlinks.
+    info!("Reading file {}", location.display());
+    let (metadata, _) = get_metadata(location, true)?; // follows symlinks.
 
     // We now compare both FilesMaps to upload the missing files
-    let mut processed_files = BTreeMap::new();
-    let normalised_path = normalise_path_separator(file_path.to_str().unwrap_or(""));
+    let mut processed_files = ProcessedFiles::default();
+    let normalised_path = PathBuf::from(normalise_path_separator(&location.display().to_string()));
     if metadata.is_dir() {
         Err(Error::InvalidInput(format!(
             "'{}' is a directory, only individual files can be added. Use files sync operation for uploading folders",
-            location
+            location.display()
         )))
     } else {
-        match upload_file_to_net(safe, file_path, dry_run).await {
+        match upload_file_to_net(safe, location, dry_run).await {
             Ok(xorurl) => {
-                processed_files.insert(normalised_path, (CONTENT_ADDED_SIGN.to_string(), xorurl));
+                processed_files.insert(normalised_path, FilesMapChange::Added(xorurl));
             }
             Err(err) => {
-                processed_files.insert(
-                    normalised_path.clone(),
-                    (CONTENT_ERROR_SIGN.to_string(), format!("{}>", err)),
-                );
-                info!("Skipping file \"{}\". {}", normalised_path, err);
+                info!("Skipping file \"{}\". {}", normalised_path.display(), err);
+                processed_files.insert(normalised_path, FilesMapChange::Failed(format!("{}", err)));
             }
         };
         Ok(processed_files)
