@@ -34,7 +34,7 @@ impl Safe {
         debug!("Creating a Multimap");
         let (xorname, op_batch) = self
             .safe_client
-            .create_register(name, type_tag, None, private)
+            .create_register(name, type_tag, None, private, dry_run)
             .await?;
 
         if !dry_run {
@@ -46,6 +46,7 @@ impl Safe {
         } else {
             Scope::Public
         };
+
         let xorurl = SafeUrl::encode_register(
             xorname,
             type_tag,
